@@ -1,8 +1,8 @@
 mod emulator_enum;
 mod emulator_tools;
 
-use crate::error::*;
-use std::{path::PathBuf, process::Command};
+use crate::{error::*, sdk_path_from_env};
+use std::process::Command;
 
 pub use emulator_enum::*;
 pub use emulator_tools::*;
@@ -16,17 +16,12 @@ impl Emulator {
     }
 }
 
+/// Find `emulator` executable binary file in SDK and initialize it
 pub fn emulator_tool() -> Result<Command> {
     if let Ok(emulator_tools) = which::which(bin!("emulator")) {
         return Ok(Command::new(emulator_tools));
     }
-    let sdk_path = {
-        let sdk_path = std::env::var("ANDROID_SDK_ROOT")
-            .ok()
-            .or_else(|| std::env::var("ANDROID_SDK_PATH").ok())
-            .or_else(|| std::env::var("ANDROID_HOME").ok());
-        PathBuf::from(sdk_path.ok_or(AndroidError::AndroidSdkNotFound)?)
-    };
+    let sdk_path = sdk_path_from_env()?;
     let build_tools = sdk_path.join("emulator");
     let emulator = build_tools.join(bin!("emulator"));
     Ok(Command::new(emulator))
